# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import json
import time

uninstallkey = []

# Defining variables
bin_latest_zip = 'Sysmon.zip'
silent_args = '-accepteula -i'
silent_args_update = '-c'
silent_args_remove = '-u force'
app_name = 'Sysmon'
app_service = 'Sysmon'
app_bin = 'Sysmon.exe'
app_unzip = makepath(app_name,app_bin)
app_dir = makepath(systemdrive, 'Windows')
app_bin_path = makepath(app_dir, app_bin)


def install():
    # Initializing variables
    package_version = control.version.split('-')[0]

    # Installing the package
    if not service_installed(app_service):
        print('Installing: %s' % app_name)
        install_exe_if_needed(app_unzip,
            silentflags=silent_args,
            min_version=package_version)

        # Adding this package to the "list-registry"
        register_windows_uninstall(control) # control is a PackageEntry object corresponding to this package
    else :
        print('Updating: %s' % app_name)
        install_exe_if_needed(app_unzip,
            silentflags=silent_args_update,
            min_version=package_version)
        if not installed_softwares (app_name):
            # Adding this package to the "list-registry"
            register_windows_uninstall(control) # control is a PackageEntry object corresponding to this package


def uninstall():
    if run(('%s %s') % (app_bin_path,silent_args_remove)) :
        remove_file(app_bin_path)
        unregister_uninstall(app_name)


def update_package():
    # Initializing variables
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    url_dl = 'https://download.sysinternals.com/files/Sysmon.zip'

    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if not isfile(bin_latest_zip):
        print('Downloading: %s' % bin_latest_zip)
        wget(url_dl, bin_latest_zip, proxies=proxies)

        # Unzip
        unzip(bin_latest_zip)
            
        # Changing version of the package
        version = get_version_from_binary(app_unzip)
        control.version = '%s-%s' % (version, control.version.split('-', 1)[-1])
        control.save_control_to_wapt()
        print("Changing package version to: %s in WAPT\\control" % control.version)


def audit ():
    # Check Sysmon Services
    if service_installed(app_service):
        return 'OK'
    else :
        return 'ERROR'



def register_windows_uninstall(package_entry):
    """ Add a windows registry key for custom installer"""
    register_uninstall(package_entry.name,
        'wapt-get remove %s' % package_entry.package,
        display_name=package_entry.name,
        display_version=package_entry.get_software_version(),
        publisher=package_entry.editor)


def get_proxies():
    import platform
    if platform.python_version_tuple()[0] == '3':
        from urllib.request import getproxies
    else:
        from urllib import getproxies
    return getproxies()


def get_proxies_from_wapt_console():
    proxies = {}
    if platform.system() == 'Windows':
        waptconsole_ini_path = makepath(user_local_appdata(), 'waptconsole', 'waptconsole.ini')
    else:
        waptconsole_ini_path = makepath(user_home_directory(), '.config', 'waptconsole', 'waptconsole.ini')
    if isfile(waptconsole_ini_path):
        proxy_wapt = inifile_readstring(waptconsole_ini_path, 'global', 'http_proxy')
        if proxy_wapt:
            proxies = {'http': proxy_wapt, 'https': proxy_wapt}
    return proxies


def get_version_from_binary(filename, parameter='ProductVersion'):
    if filename.endswith('.msi'):
        return get_msi_properties(filename)[parameter]
    else:
        return get_file_properties(filename)[parameter]



